--[[
	BagnonItem
		Functions used by the item slots in Bagnon
	
		Most of this file is directly taken from the normal bag item code
--]]

local HEX = {
	["a"] = 10,
	["b"] = 11,
	["c"] = 12,
	["d"] = 13,
	["e"] = 14,
	["f"] = 15,
	["0"] = 0,
	["1"] = 1,
	["2"] = 2,
	["3"] = 3,
	["4"] = 4,
	["5"] = 5,
	["6"] = 6,
	["7"] = 7,
	["8"] = 8,
	["9"] = 9,
};

function BagnonItem_OnLoad()
	this:RegisterForClicks("LeftButtonUp", "RightButtonUp");
	this:RegisterForDrag("LeftButton");
end

function BagnonItem_OnClick(button, ignoreModifiers)
	this:GetParent():SetID(this.bag);
	ContainerFrameItemButton_OnClick(button, ignoreModifiers);
end

--[[
	Show tooltip on hover
--]]

function BagnonItem_OnEnter(button)
	if ( not button ) then
		button = this;
	end
	
	--blizzard totally needs to make the bank button not a special case
	--I'm still hopeful that given that most mods don't use GetScript for overrides
	--this fix will still work
	if(button.bag == -1) then
		if( button:GetLeft() < ( UIParent:GetRight() / 2) ) then
			GameTooltip:SetOwner(button, "ANCHOR_RIGHT");
		else
			GameTooltip:SetOwner(button, "ANCHOR_LEFT");
		end
		GameTooltip:SetInventoryItem("player", BankButtonIDToInvSlotID(button:GetID()) );
	else
		button:GetParent():SetID(button.bag);
		ContainerFrameItemButton_OnEnter(button);
	end
	
	--EnhancedTooltip does its own anchoring, so don't anchor if its there
	if(not EnhancedTooltip) then
		--reposition tooltip based on screen position
		GameTooltip:ClearAllPoints();
		if( button:GetLeft() < ( UIParent:GetRight() / 2) ) then
			GameTooltip:SetPoint("BOTTOMLEFT", button, "TOPRIGHT", 0, 0);
		else
			GameTooltip:SetPoint("BOTTOMRIGHT", button, "TOPLEFT", 0, 0);
		end
	end
end

--[[
	Update tooltip info
--]]

function BagnonItem_OnUpdate(elapsed)
	if ( GameTooltip:IsOwned(this) ) then
		BagnonItem_OnEnter();
	end
end

--Adapted from OneBag.  The author had a clever idea of using the link to generate the color instead of getting the quality, then the color
function BagnonItem_UpdateBorder(button)

	local link = GetContainerItemLink(button.bag, button:GetID());
	
	if(link) then
		--item border coloring
		local _, _, hexString = strfind( link ,"|cff(%w+)|H");
		local red, green, blue = BagnonItem_HexToRGB(hexString);
		
		if(getglobal(button:GetName() .. "Border") and (red ~= green and red ~= blue ) ) then
			getglobal(button:GetName() .. "Border"):SetVertexColor(red, green, blue, 0.4);
			getglobal(button:GetName() .. "Border"):Show();
		else
			getglobal(button:GetName() .. "Border"):Hide();
		end
	else
		--ammo slot coloring
		getglobal(button:GetName() .. "Border"):Hide();
		if( BagnonCore_IsAmmoBag(button.bag) ) then
			getglobal(button:GetName() .. "NormalTexture"):SetVertexColor(1, 0.9, 0.1);
		else
			getglobal(button:GetName() .. "NormalTexture"):SetVertexColor(1, 1, 1);
		end
	end
end

function BagnonItem_HexToRGB(hexString)
	local red = ( 16 * HEX[string.sub(hexString, 1, 1)] + HEX[string.sub(hexString, 2, 2)] ) / 256;
	local green = ( 16 * HEX[string.sub(hexString, 3, 3)] + HEX[string.sub(hexString, 4, 4)] ) / 256;
	local blue = ( 16 * HEX[string.sub(hexString, 5, 5)] + HEX[string.sub(hexString, 6, 6)] ) / 256;
	
	return red, green, blue;
end