--[[
	BagnonForever
		Adds offline and bank viewing to Bagnon
		
	TODO
		KC_Items support
--]]

local LINK_COLOR = {
	[0] = "9d9d9d", --grey
	[1] = "ffffff", --common
	[2] = "1eff00", --uncommon
	[3] = "0070dd", -- rare
	[4] = "a335ee", --epic
	[5] = "ff8000", --legendary
	[6] = "e6cc80", --artifact
};

local atBank;

function BagnonForever_OnLoad()
	this:RegisterEvent("BANKFRAME_CLOSED");
	this:RegisterEvent("BANKFRAME_OPENED");
end

function BagnonForever_OnEvent(event)
	if(event == "BANKFRAME_CLOSED") then
		atBank = nil;
	elseif(event == "BANKFRAME_OPENED") then
		atBank = 1;
	end
end

--add any other things we need to to the frame
function BagnonForever_LoadSettings(frame, frameType)
	frame.player = UnitName("player");	
end


--[[
	Bagnon Core Overrides
--]]

BagnonCore_OnDoubleClick = function(frame)
	BagnonForeverMenu_Show(frame);
end;


local Original_BagnonCore_GenerateFrame = BagnonCore_GenerateFrame;
BagnonCore_GenerateFrame = function(frame)
	local bagFrame = getglobal(frame:GetName() .. "Bags");
	
	--update money
	if( BagnonForever_IsCachedFrame(frame) ) then
		--hide bags
		if(bagFrame) then
			getglobal(frame:GetName() .. "ShowBags"):Hide();
			bagFrame:Hide();
		end
		MoneyFrame_Update(frame:GetName() .. "MoneyFrame", BagnonDB_GetMoney(frame.player));
	else
		if(bagFrame) then
			getglobal(frame:GetName() .. "ShowBags"):Show();
			getglobal(frame:GetName() .. "ShowBags"):SetText("Show Bags");
			bagFrame:Hide();
		end
		MoneyFrame_Update(frame:GetName() .. "MoneyFrame", GetMoney());
	end
	Original_BagnonCore_GenerateFrame(frame);
	
	--correction for any frame that's completely empty
	if(frame.size == 0) then
		frame:SetHeight(64);
		frame:SetWidth(256);
		Infield_Reposition(frame, UIParent);
	end
end;

--update item slots in the frame
--not exactly useful if you're say...looking at a frame that never updates (another character's stuff)
BagnonCore_Update = function(frame)
	if(not frame.size or (UnitName("player") ~= frame.player) ) then
		return;
	end

	local frameName = frame:GetName();
	local slot;
	
	--update only the slots the player can use
	for slot = 1, frame.size, 1 do
		local item = getglobal( frameName .. "Item" .. slot );
		
		BagnonForever_UpdateItemInfo(item);
	end
end;

--adds and saves the player's inventory data to <frame>
BagnonCore_AddBag = function(frame, bagID)
	local frameName = frame:GetName();
	local slot, index, size --slot refers to the itemslot in <frame>, index refers to the item slot in <bag>
	
	if(not frame.size) then
		frame.size = 0;
		slot = 0;
	else
		slot = frame.size;
	end
	
	--update used slots
	if( BagnonForever_IsCachedBag(frame.player, bagID) ) then
		size = BagnonDB_GetBagSize(frame.player, bagID);
	else
		size = GetContainerNumSlots(bagID);
	end
	
	for index = 1, size, 1 do
		slot = slot + 1;

		local item = getglobal( frameName .. "Item".. slot);
		
		if(not item) then
			frame.size = slot - 1;
			return;
		end
		
		item:SetID(index);
		item.bag = bagID;		
		item:Show();
		
		BagnonForever_UpdateItemInfo(item);
	end
	
	
	frame.size = slot;
end;

--[[
	Update the texture, lock status, and other information about an item
		This function isn't an override
--]]

function BagnonForever_UpdateItemInfo(item)
	--if its not a cached item, then read the data in the normal way
	if( not BagnonForever_IsCachedItem(item) ) then
	
		BagnonCore_UpdateItemInfo(item);
		item.isLink = nil;
		
	--else read the data from the cache
	else
		local link, texture, count = BagnonDB_GetItemData(item);
		
		--update texture and count
		SetItemButtonTexture( item, texture );
		SetItemButtonCount( item, count );
		BagnonForever_UpdateItemBorder(item);
		
		if ( texture ) then
			item.hasItem = 1;
		else
			item.hasItem = nil;
		end
		
		item.isLink = 1;
		
		--hide cooldown since there isn't one for linked items
		getglobal(item:GetName() .. "Cooldown"):Hide();
	end	
end


--[[
	Replacement for Bagnon_Item functions
--]]

--OnClick
local Original_BagnonItem_OnClick = BagnonItem_OnClick;
BagnonItem_OnClick = function(button, ignoreModifiers)
	if ( this.isLink ) then
		if(this.hasItem) then
			if ( button == "LeftButton" ) then
				if ( IsControlKeyDown() ) then
					DressUpItemLink( BagnonDB_GetItemLink(this) );
				elseif( IsShiftKeyDown() ) then
					ChatFrameEditBox:Insert( BagnonDB_GetFullItemLink(this) );
				end
			end
		end
	else
		Original_BagnonItem_OnClick(button, ignoreModifiers);
	end
end;

--OnHover: slightly less efficient than the original method
local Original_BagnonItem_OnEnter = BagnonItem_OnEnter;
BagnonItem_OnEnter = function(button)
	if ( not button ) then
		button = this;
	end
	
	--link case
	if(button.isLink) then
		if(button.hasItem)then
		
			if( button:GetLeft() < ( UIParent:GetRight() / 2) ) then
				GameTooltip:SetOwner(button, "ANCHOR_RIGHT");
			else
				GameTooltip:SetOwner(button, "ANCHOR_LEFT");
			end
				
			GameTooltip:SetHyperlink( BagnonDB_GetItemLink(button) );
			GameTooltip:Show();
			
		end
	--normal bag case
	else
		Original_BagnonItem_OnEnter(button);
	end
end;

--[[
	Utility Functions
--]]


function BagnonForever_IsCachedFrame(frame) 
	return ( UnitName("player") ~= frame.player or ( frame:GetName() == "Banknon" and not atBank ) );
end

function BagnonForever_IsCachedBag(player, bagID) 
	return ( UnitName("player") ~= player or ( BagnonCore_IsBankBag(bagID) and not atBank ) );
end

--returns true if the item is being viewed from a cache 
function BagnonForever_IsCachedItem(item)
	--we're not looking at the current player's items
	if( UnitName("player") ~= item:GetParent().player ) then
		return true;
	end
	
	--the bank frame is visible in the normal way
	if( atBank ) then
		return false;
	end
	
	--we're looking at the player's bank away from the actual bank
	return ( BagnonCore_IsBankBag(item.bag) );
end

--Adapted from OneBag.  The author had a clever idea of using the link to generate the color instead of getting the quality, then the color
function BagnonForever_UpdateItemBorder(item)
	local id = BagnonDB_GetItemID(item);
	
	if(id) then
		local name, link, quality = GetItemInfo( id );
		local red, green, blue = BagnonItem_HexToRGB(LINK_COLOR[quality]);
		
		if(getglobal(item:GetName() .. "Border") and (red ~= green and red ~= blue ) ) then
			getglobal(item:GetName() .. "Border"):SetVertexColor(red, green, blue, 0.4);
			getglobal(item:GetName() .. "Border"):Show();
		else
			getglobal(item:GetName() .. "Border"):Hide();
		end
	else
		getglobal(item:GetName() .. "Border"):Hide();
	end
end