--[[
	Banknon 
		Combines the player's bank into a single frame
--]]

--Local constants
local MAX_BAGS = 10;
local MAX_SLOTS = 192; --total number of slots, taken from the blizzard bank's XML

--[[ 
	Loading Functions
--]]

function Banknon_OnLoad()
	this:RegisterEvent("ADDON_LOADED");
end

--[[
	Event Handler
--]]

function Banknon_OnEvent(event)
	if ( event == "BANKFRAME_OPENED" ) then
		BagnonCore_GenerateFrame(Banknon);
	elseif( event == "BANKFRAME_CLOSED" ) then
		Banknon:Hide();
	elseif ( event == "ADDON_LOADED" and arg1 == "Banknon") then
		this:UnregisterEvent("ADDON_LOADED");
		Banknon_Load();
	end
end

function Banknon_Load()
	BagnonCore_LoadSettings(Banknon, MAX_SLOTS, Banknon_AddBags, "Bank");
	Banknon_AddBagHooks();
	
	if(CT_BankFrame_AcceptFrame) then
		CT_BankFrame_AcceptFrame:SetParent(Banknon);
	end
	
	Banknon:RegisterEvent("BANKFRAME_CLOSED");
	Banknon:RegisterEvent("BANKFRAME_OPENED");
end

--[[
	Add all usable bag slots to Banknon and resize
--]]

function Banknon_AddBags()
	BagnonCore_AddBag(Banknon, -1);
	
	for bag = 5, MAX_BAGS, 1 do
		BagnonCore_AddBag(Banknon, bag);
	end
end

--[[
	UI Functions
--]]

--OnShow
function Banknon_OnShow()
	PlaySound("igMainMenuOpen");
end

--OnHide
function Banknon_OnHide()
	PlaySound("igMainMenuClose");
	CloseBankFrame();
end

--[[
	Bank Slots functions
--]]


--[[ Show/Hide the bag frame ]]--

function Banknon_ToggleSlots()
	if( not BanknonBags:IsShown() ) then
		BanknonBags:Show();
		--Banknon:SetHeight(Banknon:GetHeight() + ( BanknonBags:GetHeight() ) );
		this:SetText("Hide Bag Slots");
	else
		BanknonBags:Hide();
		--Banknon:SetHeight(Banknon:GetHeight() - ( BanknonBags:GetHeight() ) );
		this:SetText("Show Bag Slots");
	end
	
	BagnonCore_TrimToSize(Banknon);
end


--[[
	Reposition the bank bags, purchase, and price buttons to the BankSlots frame
--]]
function BanknonBankSlots_OnLoad()
	
	--position purchase button
	BankFramePurchaseButton:ClearAllPoints();
	BankFramePurchaseButton:SetPoint("TOPLEFT", this, "TOPLEFT", 8, -2);
	BankFramePurchaseButton:SetParent(this);
	
	--position slot purchase cost
	BankFrameDetailMoneyFrame:ClearAllPoints();
	BankFrameDetailMoneyFrame:SetPoint("LEFT", BankFramePurchaseButton, "RIGHT", 4, 0);
	BankFrameDetailMoneyFrame:SetParent(this);
	
	--position bank bags
	BankFrameBag1:ClearAllPoints();
	BankFrameBag1:SetPoint("TOPLEFT", BankFramePurchaseButton, "BOTTOMLEFT", 4, -4);
	BankFrameBag1:SetParent(this);
	
	local bag;
	
	for i = 2, 6, 1 do
		bag = getglobal("BankFrameBag" .. i);
		bag:ClearAllPoints();
		bag:SetPoint("LEFT", getglobal("BankFrameBag" .. i - 1), "RIGHT", 4, 0);
		bag:SetParent(this);
	end
	
	UpdateBagSlotStatus();
end

--[[
	BagSlot Overrides
--]]

function Banknon_AddBagHooks()
	local i;
	for i = 1, 6 do
		getglobal("BankFrameBag" .. i):SetScript("OnEnter", BanknonBag_OnEnter);
		getglobal("BankFrameBag" .. i):SetScript("OnLeave", BanknonBag_OnLeave);
	end
end


function BanknonBag_OnEnter()
	if( this:GetLeft() < ( UIParent:GetRight() / 2) ) then
		GameTooltip:SetOwner(this, "ANCHOR_RIGHT");
	else
		GameTooltip:SetOwner(this, "ANCHOR_LEFT");
	end
	GameTooltip:SetText(this.tooltipText);
	CursorUpdate();
	
	if(Banknon:IsShown() ) then
		BagnonCore_HighlightSlots(Banknon, this:GetID());
	end
end;

function BanknonBag_OnLeave()
	GameTooltip:Hide();
	ResetCursor();
	BagnonCore_UnhighlightAll(Banknon);
end